Test Report

# Summary

Started | 2025-09-29 09:48:54
Ended | 2025-09-29 09:58:13
Duration | 0:09:18.617036
Total run time | 0:09:00.120753

100 passed 5 skipped

# Warnings

## Warnings 189

- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:98
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:102
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:73
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:67
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:115
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:107
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/polymer_enmap.py:53
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/level1_enmap.py:67
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Automatic nodata value detection returned the value 0.0 for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER' but this seems to be unreliable (occurs in only 2 image corners). To avoid automatic detection, just pass the correct nodata value.
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/geoarray/baseclasses.py:806
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=174) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66

# Tests

## tests/test_cli_parser.py 7 0:00:00.999636

### PASSED Test_CLIParser::test_json_opts 0:00:00.310933

Started | 2025-09-29 09:49:09
Ended | 2025-09-29 09:49:09
Duration | 0:00:00.310933
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_output_nodata_value 0:00:00.186672

Started | 2025-09-29 09:49:09
Ended | 2025-09-29 09:49:09
Duration | 0:00:00.186672
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_acceptance 0:00:00.128765

Started | 2025-09-29 09:49:09
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.128765
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_boolean 0:00:00.170964

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.170964
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_list 0:00:00.046132

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.046132
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtepsg 0:00:00.080515

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.080515
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtprj 0:00:00.075654

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.075654
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_config.py 13 0:00:00.346545

### PASSED Test_get_options::test_target_is_file_no_validation 0:00:00.007964

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.007964
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_get_options::test_target_is_file_validation 0:00:00.015613

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.015613
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_invalid_filepath 0:00:00.034132

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.034132
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_file 0:00:00.039804

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.039804
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_param_acceptance 0:00:00.033189

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.033189
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_allfine 0:00:00.033174

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.033174
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_badcomment 0:00:00.016060

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.016060
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_nojson 0:00:00.015816

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.015816
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_schema_violation 0:00:00.024848

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.024848
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_undecodable_val 0:00:00.016075

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.016075
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_plain_args 0:00:00.033671

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.033671
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_dict_validity 0:00:00.041890

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.041890
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_jsonable_dict 0:00:00.034310

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:10
Duration | 0:00:00.034310
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_controller.py 5 0:03:10.696443

### PASSED Test_EnPT_Controller::test_run_all_processors 0:00:08.250392

Started | 2025-09-29 09:49:10
Ended | 2025-09-29 09:49:19
Duration | 0:00:08.250392
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': True,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': True,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/dem_map_geo.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest1_CWV2_SM0.zip',
                      'path_l1b_enmap_image_gapfill': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest2_CWV2_SM0.zip',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpst634lof'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': False,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/29 09:49:11:   Reading metadata for VNIR detector...
    2025/09/29 09:49:11:   Calculating solar irradiance...
    2025/09/29 09:49:11:   Reading metadata for SWIR detector...
    2025/09/29 09:49:11:   Calculating solar irradiance...
    2025/09/29 09:49:11:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:49:12:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:49:12:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:49:12:   Reading metadata for VNIR detector...
    2025/09/29 09:49:12:   Calculating solar irradiance...
    2025/09/29 09:49:12:   Reading metadata for SWIR detector...
    2025/09/29 09:49:12:   Calculating solar irradiance...
    2025/09/29 09:49:12:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:49:12:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:49:12:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:49:12:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:49:12:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:49:12:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:49:12:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:49:13:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:49:14:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:49:14:   Skipping atmospheric correction as configured and computing top-of-atmosphere reflectance instead.
    2025/09/29 09:49:14:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/09/29 09:49:14:   Converting TOA radiance to TOA reflectance for SWIR detector...
    2025/09/29 09:49:14:   Starting orthorectification...
    2025/09/29 09:49:14:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257740.0, 656040.0, 5266620.0)
    2025/09/29 09:49:14:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:49:15:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:49:16:   Merging VNIR and SWIR data...
    2025/09/29 09:49:16:   Orthorectifying 'mask_clouds' attribute...
    2025/09/29 09:49:17:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/29 09:49:17:   Generating L2A metadata...
    2025/09/29 09:49:18:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (296, 958, 209) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.TIF.
    Writing GeoArray of size (296, 958) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:49:19:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_header.xml
    2025/09/29 09:49:19:   L2A product successfully written!
    2025/09/29 09:49:19:   Total runtime of the processing chain: 0:00:08.182962

##### Captured stderr call

    2025/09/29 09:49:12:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:49:12:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:49:12:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:49:12:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:49:12:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:49:18:   The 'mask_landwater' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:49:18:   The 'mask_cloudshadow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:49:18:   The 'mask_haze' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:49:18:   The 'mask_snow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:49:18:   The 'mask_cirrus' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:49:19:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/29 09:49:19:   The 'sicor_cwv' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:49:19:   The 'sicor_liq' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:49:19:   The 'sicor_ice' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:49:19:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:49:19:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:49:19:   No XML metadata conversion implemented for datasets different to the DLR format.Metadata XML file will be empty.

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata::test_run_all_processors 0:01:00.254268

Started | 2025-09-29 09:49:19
Ended | 2025-09-29 09:50:19
Duration | 0:01:00.254268
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 24,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-799.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpqp9br8zc'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': True,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/T30TXQ_20170218T110111_B05__sub.tif'},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/29 09:49:19:   Reading metadata for VNIR detector...
    2025/09/29 09:49:19:   Calculating solar irradiance...
    2025/09/29 09:49:19:   Reading metadata for SWIR detector...
    2025/09/29 09:49:20:   Calculating solar irradiance...
    2025/09/29 09:49:20:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:49:20:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:49:20:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:49:20:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:49:21:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:49:21:   Computing VNIR geolayer...
    2025/09/29 09:49:21:   Computing SWIR geolayer...
    2025/09/29 09:49:22:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/09/29 09:49:22:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/09/29 09:49:22:   Preparing reference image for co-registration.
    2025/09/29 09:49:22:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/09/29 09:49:34:   Generating misregistration array.
    interpolation runtime: 0.19s
    interpolation runtime: 0.17s
    2025/09/29 09:49:34:   Transforming spatial optimization results back to sensor geometry.
    2025/09/29 09:49:34:   Applying results of spatial optimization to geolayer.
    2025/09/29 09:49:34:   Pre-processing DEM for VNIR...
    2025/09/29 09:49:34:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/09/29 09:49:35:   Pre-processing DEM for SWIR...
    2025/09/29 09:49:35:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/09/29 09:49:35:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/09/29 09:49:35:   Starting atmospheric correction for VNIR and SWIR detector in 'land' mode. Source radiometric unit code is 'TOARad'.
    2025/09/29 09:49:35:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/09/29 09:49:35:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 24,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/09/29 09:49:35:   Setting up forward operator...
    2025/09/29 09:49:35:   SICOR is applied to land AND water pixels.
    2025/09/29 09:49:35:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/09/29 09:49:37:   Getting observation metadata...
    2025/09/29 09:49:37:   Checking if observation metadata values are within LUT value ranges...
    2025/09/29 09:49:37:   Loading solar irradiance model...
    2025/09/29 09:49:37:   Loading RT LUT...
    2025/09/29 09:49:37:   LUT file was properly downloaded and is available for AC!
    2025/09/29 09:49:37:   Converting LUT to Fontenla solar model...
    2025/09/29 09:49:37:   Resampling LUT to EnMAP wavelengths...
    2025/09/29 09:49:56:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/09/29 09:49:57:   Calculating absorption coefficients of liquid water and ice...
    2025/09/29 09:49:57:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/09/29 09:49:58:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/09/29 09:49:59:   Performing first guess liquid water retrieval based on the NDWI...
    2025/09/29 09:49:59:   Performing first guess ice retrieval based on the NDSI...
    2025/09/29 09:49:59:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/09/29 09:49:59:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/09/29 09:50:00:   Preparing segmented SWIR L1B data cube...
    2025/09/29 09:50:01:   Performing 3 phases of water retrieval...
    2025/09/29 09:50:01:   Setting up multiprocessing...
    2025/09/29 09:50:01:   Multiprocessing on 24 cpu's
    2025/09/29 09:50:01:   Preparing optimal estimation input...
    2025/09/29 09:50:01:   Optimization...
    2025/09/29 09:50:03:   Done!
    2025/09/29 09:50:03:   Runtime: 2.41 s
    2025/09/29 09:50:03:   Smoothing segmented CWV retrieval map...
    2025/09/29 09:50:03:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/09/29 09:50:03:   Starting surface reflectance retrieval...
    2025/09/29 09:50:03:   Calculating surface reflectance for vnir detector...
    2025/09/29 09:50:07:   Calculating surface reflectance for swir detector...
    2025/09/29 09:50:12:   Smoothing segmented liquid water and ice maps...
    2025/09/29 09:50:12:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/09/29 09:50:12:   Joining results of atmospheric correction.
    2025/09/29 09:50:13:   Starting orthorectification...
    2025/09/29 09:50:13:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636960.0, 4940670.0, 666090.0, 4949310.0)
    2025/09/29 09:50:13:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:50:14:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:50:15:   Merging VNIR and SWIR data...
    2025/09/29 09:50:15:   Orthorectifying 'mask_landwater' attribute...
    2025/09/29 09:50:15:   Orthorectifying 'mask_clouds' attribute...
    2025/09/29 09:50:15:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/29 09:50:16:   Orthorectifying 'mask_haze' attribute...
    2025/09/29 09:50:16:   Orthorectifying 'mask_snow' attribute...
    2025/09/29 09:50:16:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/29 09:50:16:   Orthorectifying 'sicor_cwv' attribute...
    2025/09/29 09:50:16:   Orthorectifying 'sicor_liq' attribute...
    2025/09/29 09:50:17:   Orthorectifying 'sicor_ice' attribute...
    2025/09/29 09:50:17:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/29 09:50:17:   Generating L2A metadata...
    2025/09/29 09:50:18:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (288, 971, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_CWV.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_LIQ.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_ICE.TIF.
    2025/09/29 09:50:19:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/09/29 09:50:19:   L2A product successfully written!
    2025/09/29 09:50:19:   Total runtime of the processing chain: 0:01:00.190290

##### Captured stderr call

    2025/09/29 09:49:19:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/09/29 09:49:22:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.1% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.4% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.3% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.2% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.6% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.2% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.3% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.2% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.3% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.4% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.2% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.2% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.1% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.6% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.2% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.6% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.3% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.3% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.6% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.4% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.2% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.3% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.4% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.3% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.1% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.6% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.6% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.2% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.7% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.3% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.3% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.2% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.3% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.3% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.2% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.5% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.4% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.3% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.3% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.1% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.1% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.4% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.5% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.5% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.1% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.0% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.0% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.2% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.3% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.3% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.0% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.3% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.4% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.2% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.1% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.2% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.2% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:10
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:10
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:10
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:10
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:10
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:10
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:10
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:10
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:10
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:10
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:10
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:10
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:10
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:10
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:10
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:10
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:10
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:10
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:10
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:10
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:10
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:10
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:10
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:10
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:10
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:10
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:10
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:10
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:10
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:10
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:10
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:10
    	progress: |============================----------------------| 55.3% Complete  => 0:00:10
    	progress: |============================----------------------| 55.9% Complete  => 0:00:10
    	progress: |============================----------------------| 56.5% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:10
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:10
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:10
    	progress: |================================------------------| 63.4% Complete  => 0:00:10
    	progress: |================================------------------| 64.0% Complete  => 0:00:10
    	progress: |================================------------------| 64.6% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:10
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:10
    	progress: |==================================----------------| 67.1% Complete  => 0:00:10
    	progress: |==================================----------------| 67.7% Complete  => 0:00:10
    	progress: |==================================----------------| 68.3% Complete  => 0:00:10
    	progress: |==================================----------------| 68.9% Complete  => 0:00:10
    	progress: |===================================---------------| 69.6% Complete  => 0:00:10
    	progress: |===================================---------------| 70.2% Complete  => 0:00:10
    	progress: |===================================---------------| 70.8% Complete  => 0:00:10
    	progress: |====================================--------------| 71.4% Complete  => 0:00:10
    	progress: |====================================--------------| 72.0% Complete  => 0:00:10
    	progress: |====================================--------------| 72.7% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:10
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:10
    	progress: |======================================------------| 75.2% Complete  => 0:00:10
    	progress: |======================================------------| 75.8% Complete  => 0:00:10
    	progress: |======================================------------| 76.4% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:10
    	progress: |========================================----------| 79.5% Complete  => 0:00:10
    	progress: |========================================----------| 80.1% Complete  => 0:00:10
    	progress: |========================================----------| 80.7% Complete  => 0:00:10
    	progress: |=========================================---------| 81.4% Complete  => 0:00:10
    	progress: |=========================================---------| 82.0% Complete  => 0:00:10
    	progress: |=========================================---------| 82.6% Complete  => 0:00:10
    	progress: |==========================================--------| 83.2% Complete  => 0:00:10
    	progress: |==========================================--------| 83.9% Complete  => 0:00:10
    	progress: |==========================================--------| 84.5% Complete  => 0:00:10
    	progress: |===========================================-------| 85.1% Complete  => 0:00:10
    	progress: |===========================================-------| 85.7% Complete  => 0:00:10
    	progress: |===========================================-------| 86.3% Complete  => 0:00:10
    	progress: |===========================================-------| 87.0% Complete  => 0:00:10
    	progress: |============================================------| 87.6% Complete  => 0:00:10
    	progress: |============================================------| 88.2% Complete  => 0:00:10
    	progress: |============================================------| 88.8% Complete  => 0:00:10
    	progress: |=============================================-----| 89.4% Complete  => 0:00:10
    	progress: |=============================================-----| 90.1% Complete  => 0:00:10
    	progress: |=============================================-----| 90.7% Complete  => 0:00:10
    	progress: |==============================================----| 91.3% Complete  => 0:00:10
    	progress: |==============================================----| 91.9% Complete  => 0:00:10
    	progress: |==============================================----| 92.5% Complete  => 0:00:10
    	progress: |===============================================---| 93.2% Complete  => 0:00:10
    	progress: |===============================================---| 93.8% Complete  => 0:00:10
    	progress: |===============================================---| 94.4% Complete  => 0:00:10
    	progress: |================================================--| 95.0% Complete  => 0:00:10
    	progress: |================================================--| 95.7% Complete  => 0:00:10
    	progress: |================================================--| 96.3% Complete  => 0:00:10
    	progress: |================================================--| 96.9% Complete  => 0:00:10
    	progress: |=================================================-| 97.5% Complete  => 0:00:10
    	progress: |=================================================-| 98.1% Complete  => 0:00:10
    	progress: |=================================================-| 98.8% Complete  => 0:00:10
    	progress: |==================================================| 99.4% Complete  => 0:00:10
    	progress: |==================================================| 100.0% Complete  => 0:00:10

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.9% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.8% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.8% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 6.7% Complete  => 0:00:00
    	progress: |=======-------------------------------------------| 13.3% Complete  => 0:00:00
    	progress: |===========---------------------------------------| 22.7% Complete  => 0:00:00
    	progress: |=================---------------------------------| 34.7% Complete  => 0:00:00
    	progress: |========================--------------------------| 48.9% Complete  => 0:00:01
    	progress: |================================------------------| 63.6% Complete  => 0:00:01
    	progress: |=======================================-----------| 78.7% Complete  => 0:00:01
    	progress: |=================================================-| 98.7% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/09/29 09:50:12:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/29 09:50:12:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/29 09:50:19:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/29 09:50:19:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:50:19:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:50:19:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_import_polymer 0:00:00.038451

Started | 2025-09-29 09:50:19
Ended | 2025-09-29 09:50:19
Duration | 0:00:00.038451
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors 0:01:23.598631

Started | 2025-09-29 09:50:19
Ended | 2025-09-29 09:51:42
Duration | 0:01:23.598631
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpc_lcfbhj'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/29 09:50:19:   Reading metadata for VNIR detector...
    2025/09/29 09:50:19:   Calculating solar irradiance...
    2025/09/29 09:50:19:   Reading metadata for SWIR detector...
    2025/09/29 09:50:20:   Calculating solar irradiance...
    2025/09/29 09:50:20:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:50:20:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:50:20:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:50:20:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:50:20:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:50:20:   Computing VNIR geolayer...
    2025/09/29 09:50:20:   Computing SWIR geolayer...
    2025/09/29 09:50:20:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/29 09:50:21:   Percentage of defective pixels: 0.49
    2025/09/29 09:50:21:   Percentage of pixels with a defect in any band: 35.60
    2025/09/29 09:50:21:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/29 09:50:21:   Percentage of defective pixels: 0.50
    2025/09/29 09:50:21:   Percentage of pixels with a defect in any band: 44.50
    2025/09/29 09:50:21:   Pre-processing DEM for VNIR...
    2025/09/29 09:50:21:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/09/29 09:50:21:   Pre-processing DEM for SWIR...
    2025/09/29 09:50:21:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/09/29 09:50:21:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/09/29 09:50:21:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/09/29 09:50:21:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': True,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/09/29 09:50:21:   Setting up forward operator...
    2025/09/29 09:50:21:   SICOR is applied to land pixels only. This may result in edge effects, e.g., at coastlines...
    2025/09/29 09:50:22:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/09/29 09:50:22:   Getting observation metadata...
    2025/09/29 09:50:22:   Checking if observation metadata values are within LUT value ranges...
    2025/09/29 09:50:22:   Loading solar irradiance model...
    2025/09/29 09:50:22:   Loading RT LUT...
    2025/09/29 09:50:22:   LUT file was properly downloaded and is available for AC!
    2025/09/29 09:50:23:   Converting LUT to Fontenla solar model...
    2025/09/29 09:50:23:   Resampling LUT to EnMAP wavelengths...
    2025/09/29 09:50:43:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/09/29 09:50:43:   Calculating absorption coefficients of liquid water and ice...
    2025/09/29 09:50:44:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/09/29 09:50:45:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/09/29 09:50:45:   Performing first guess liquid water retrieval based on the NDWI...
    2025/09/29 09:50:45:   Performing first guess ice retrieval based on the NDSI...
    2025/09/29 09:50:45:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/09/29 09:50:45:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/09/29 09:50:45:   Preparing segmented SWIR L1B data cube...
    2025/09/29 09:50:45:   Performing 3 phases of water retrieval...
    2025/09/29 09:50:45:   Setting up multiprocessing...
    2025/09/29 09:50:45:   Multiprocessing on 16 cpu's
    2025/09/29 09:50:45:   Preparing optimal estimation input...
    2025/09/29 09:50:45:   Optimization...
    2025/09/29 09:50:47:   Done!
    2025/09/29 09:50:47:   Runtime: 1.39 s
    2025/09/29 09:50:47:   Smoothing segmented CWV retrieval map...
    2025/09/29 09:50:47:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/09/29 09:50:47:   Starting surface reflectance retrieval...
    2025/09/29 09:50:47:   Calculating surface reflectance for vnir detector...
    2025/09/29 09:50:48:   Calculating surface reflectance for swir detector...
    2025/09/29 09:50:50:   Smoothing segmented liquid water and ice maps...
    2025/09/29 09:50:50:   SICOR atmospheric correction for EnMAP in combined mode successfully finished!
    vnir
    2025/09/29 09:50:50:   Running polymer...
    Initializing ENMAP product of size (30, 1000)
    2025/09/29 09:50:50:   Landmask is EnMAP L1B
    Starting processing at 2025-09-29 09:50:50.695189
    Processing block: size (30, 1000), offset (0, 0)
    Done in 0:00:47.202415
    2025/09/29 09:51:37:   Joining results of atmospheric correction.
    2025/09/29 09:51:38:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/09/29 09:51:38:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/29 09:51:38:   Percentage of defective pixels: 0.49
    2025/09/29 09:51:38:   Percentage of pixels with a defect in any band: 35.60
    2025/09/29 09:51:38:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/29 09:51:38:   Percentage of defective pixels: 0.50
    2025/09/29 09:51:38:   Percentage of pixels with a defect in any band: 44.50
    2025/09/29 09:51:38:   Starting orthorectification...
    2025/09/29 09:51:38:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/09/29 09:51:38:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:51:38:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:51:39:   Merging VNIR and SWIR data...
    2025/09/29 09:51:39:   Orthorectifying 'mask_landwater' attribute...
    2025/09/29 09:51:39:   Orthorectifying 'mask_clouds' attribute...
    2025/09/29 09:51:39:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/29 09:51:39:   Orthorectifying 'mask_haze' attribute...
    2025/09/29 09:51:39:   Orthorectifying 'mask_snow' attribute...
    2025/09/29 09:51:40:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/29 09:51:40:   Orthorectifying 'sicor_cwv' attribute...
    2025/09/29 09:51:40:   Orthorectifying 'sicor_liq' attribute...
    2025/09/29 09:51:40:   Orthorectifying 'sicor_ice' attribute...
    2025/09/29 09:51:40:   Orthorectifying 'polymer_logchl' attribute...
    2025/09/29 09:51:40:   Orthorectifying 'polymer_logfb' attribute...
    2025/09/29 09:51:41:   Orthorectifying 'polymer_rgli' attribute...
    2025/09/29 09:51:41:   Orthorectifying 'polymer_rnir' attribute...
    2025/09/29 09:51:41:   Orthorectifying 'polymer_bitmask' attribute...
    2025/09/29 09:51:41:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/29 09:51:41:   Generating L2A metadata...
    2025/09/29 09:51:42:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_CWV.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_LIQ.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_ICE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGCHL.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGFB.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RGLI.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RNIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_BITMASK.TIF.
    2025/09/29 09:51:42:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/09/29 09:51:42:   L2A product successfully written!
    2025/09/29 09:51:42:   Total runtime of the processing chain: 0:01:23.530137

##### Captured stderr call

    2025/09/29 09:50:19:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 2.4% Complete  => 0:00:00
    	progress: |===========---------------------------------------| 22.0% Complete  => 0:00:00
    	progress: |=============================---------------------| 58.5% Complete  => 0:00:00
    	progress: |==================================================| 100.0% Complete  => 0:00:00
    2025/09/29 09:50:50:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/29 09:50:50:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/29 09:51:42:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/29 09:51:42:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:51:42:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:51:42:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors_without_acwater_installed 0:00:38.554701

Test to run all processors while replacing polymer_ac_enmap with None using mock.patch.

Started | 2025-09-29 09:51:42
Ended | 2025-09-29 09:52:21
Duration | 0:00:38.554701
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpfe5nzgl1'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/29 09:51:43:   Reading metadata for VNIR detector...
    2025/09/29 09:51:43:   Calculating solar irradiance...
    2025/09/29 09:51:43:   Reading metadata for SWIR detector...
    2025/09/29 09:51:43:   Calculating solar irradiance...
    2025/09/29 09:51:43:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:51:44:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:51:44:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:51:44:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:51:44:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:51:44:   Computing VNIR geolayer...
    2025/09/29 09:51:44:   Computing SWIR geolayer...
    2025/09/29 09:51:44:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/29 09:51:44:   Percentage of defective pixels: 0.49
    2025/09/29 09:51:44:   Percentage of pixels with a defect in any band: 35.60
    2025/09/29 09:51:44:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/29 09:51:44:   Percentage of defective pixels: 0.50
    2025/09/29 09:51:44:   Percentage of pixels with a defect in any band: 44.50
    2025/09/29 09:51:44:   Pre-processing DEM for VNIR...
    2025/09/29 09:51:44:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/09/29 09:51:45:   Pre-processing DEM for SWIR...
    2025/09/29 09:51:45:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/09/29 09:51:45:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/09/29 09:51:45:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/09/29 09:51:45:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/09/29 09:51:45:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/09/29 09:51:45:   Setting up forward operator...
    2025/09/29 09:51:45:   SICOR is applied to land AND water pixels.
    2025/09/29 09:51:45:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/09/29 09:51:46:   Getting observation metadata...
    2025/09/29 09:51:46:   Checking if observation metadata values are within LUT value ranges...
    2025/09/29 09:51:46:   Loading solar irradiance model...
    2025/09/29 09:51:46:   Loading RT LUT...
    2025/09/29 09:51:46:   LUT file was properly downloaded and is available for AC!
    2025/09/29 09:51:46:   Converting LUT to Fontenla solar model...
    2025/09/29 09:51:46:   Resampling LUT to EnMAP wavelengths...
    2025/09/29 09:52:08:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/09/29 09:52:08:   Calculating absorption coefficients of liquid water and ice...
    2025/09/29 09:52:09:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/09/29 09:52:10:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/09/29 09:52:10:   Performing first guess liquid water retrieval based on the NDWI...
    2025/09/29 09:52:10:   Performing first guess ice retrieval based on the NDSI...
    2025/09/29 09:52:10:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/09/29 09:52:10:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/09/29 09:52:10:   Preparing segmented SWIR L1B data cube...
    2025/09/29 09:52:11:   Performing 3 phases of water retrieval...
    2025/09/29 09:52:11:   Setting up multiprocessing...
    2025/09/29 09:52:11:   Multiprocessing on 16 cpu's
    2025/09/29 09:52:11:   Preparing optimal estimation input...
    2025/09/29 09:52:11:   Optimization...
    2025/09/29 09:52:13:   Done!
    2025/09/29 09:52:13:   Runtime: 2.20 s
    2025/09/29 09:52:13:   Smoothing segmented CWV retrieval map...
    2025/09/29 09:52:13:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/09/29 09:52:13:   Starting surface reflectance retrieval...
    2025/09/29 09:52:13:   Calculating surface reflectance for vnir detector...
    2025/09/29 09:52:15:   Calculating surface reflectance for swir detector...
    2025/09/29 09:52:17:   Smoothing segmented liquid water and ice maps...
    2025/09/29 09:52:17:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/09/29 09:52:17:   Joining results of atmospheric correction.
    2025/09/29 09:52:17:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/09/29 09:52:17:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/29 09:52:17:   Percentage of defective pixels: 0.49
    2025/09/29 09:52:17:   Percentage of pixels with a defect in any band: 35.60
    2025/09/29 09:52:17:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/29 09:52:17:   Percentage of defective pixels: 0.50
    2025/09/29 09:52:17:   Percentage of pixels with a defect in any band: 44.50
    2025/09/29 09:52:17:   Starting orthorectification...
    2025/09/29 09:52:17:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/09/29 09:52:17:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:52:18:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:52:18:   Merging VNIR and SWIR data...
    2025/09/29 09:52:18:   Orthorectifying 'mask_landwater' attribute...
    2025/09/29 09:52:18:   Orthorectifying 'mask_clouds' attribute...
    2025/09/29 09:52:19:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/29 09:52:19:   Orthorectifying 'mask_haze' attribute...
    2025/09/29 09:52:19:   Orthorectifying 'mask_snow' attribute...
    2025/09/29 09:52:19:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/29 09:52:19:   Orthorectifying 'sicor_cwv' attribute...
    2025/09/29 09:52:19:   Orthorectifying 'sicor_liq' attribute...
    2025/09/29 09:52:19:   Orthorectifying 'sicor_ice' attribute...
    2025/09/29 09:52:20:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/29 09:52:20:   Generating L2A metadata...
    2025/09/29 09:52:21:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_CWV.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_LIQ.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_ICE.TIF.
    2025/09/29 09:52:21:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/09/29 09:52:21:   L2A product successfully written!
    2025/09/29 09:52:21:   Total runtime of the processing chain: 0:00:38.505901

##### Captured stderr call

    2025/09/29 09:51:43:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/09/29 09:51:45:   Polymer is not callable. As a fallback, SICOR is applied to water surfaces instead.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 3.0% Complete  => 0:00:00
    	progress: |====----------------------------------------------| 7.2% Complete  => 0:00:00
    	progress: |========------------------------------------------| 15.1% Complete  => 0:00:00
    	progress: |=========-----------------------------------------| 18.7% Complete  => 0:00:00
    	progress: |=============-------------------------------------| 25.9% Complete  => 0:00:00
    	progress: |========================--------------------------| 47.6% Complete  => 0:00:00
    	progress: |============================----------------------| 56.6% Complete  => 0:00:00
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:01
    	progress: |====================================--------------| 72.9% Complete  => 0:00:01
    	progress: |=============================================-----| 89.2% Complete  => 0:00:01
    	progress: |==================================================| 99.4% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/09/29 09:52:17:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/29 09:52:17:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/29 09:52:21:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/29 09:52:21:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:52:21:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:52:21:   The 'polymer_logchl' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:52:21:   The 'polymer_logfb' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:52:21:   The 'polymer_rgli' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:52:21:   The 'polymer_rnir' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:52:21:   The 'polymer_bitmask' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/29 09:52:21:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

## tests/test_dead_pixel_correction.py 15 0:00:08.221347

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spatial 0:00:03.853014

Started | 2025-09-29 09:52:21
Ended | 2025-09-29 09:52:25
Duration | 0:00:03.853014
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spectral 0:00:00.100935

Started | 2025-09-29 09:52:25
Ended | 2025-09-29 09:52:25
Duration | 0:00:00.100935
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spatial 0:00:04.011941

Started | 2025-09-29 09:52:25
Ended | 2025-09-29 09:52:29
Duration | 0:00:04.011941
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spectral 0:00:00.176640

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.176640
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_0 0:00:00.002970

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.002970
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_1 0:00:00.002526

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.002526
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_bad_args 0:00:00.001188

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.001188
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_2d 0:00:00.001935

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.001935
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_0 0:00:00.002751

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.002751
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_1 0:00:00.003357

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.003357
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_2 0:00:00.051292

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.051292
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_bad_args 0:00:00.001301

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.001301
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_bad_args 0:00:00.001226

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.001226
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_pandas 0:00:00.005174

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.005174
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_scipy 0:00:00.005099

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.005099
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_dem_preprocessing.py 8 0:00:00.387750

### PASSED Test_DEM_Processor::test_compute_aspect 0:00:00.064802

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.064802
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_compute_slopes 0:00:00.025864

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.025864
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_fill_gaps 0:00:00.023681

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.023681
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_get_flat_dem 0:00:00.032865

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.032865
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_demTooSmall 0:00:00.033114

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:29
Duration | 0:00:00.033114
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_noWGS84 0:00:00.026031

Started | 2025-09-29 09:52:29
Ended | 2025-09-29 09:52:30
Duration | 0:00:00.026031
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_nomapinfo 0:00:00.023677

Started | 2025-09-29 09:52:30
Ended | 2025-09-29 09:52:30
Duration | 0:00:00.023677
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_to_sensor_geometry 0:00:00.157717

Started | 2025-09-29 09:52:30
Ended | 2025-09-29 09:52:30
Duration | 0:00:00.157717
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_images_sensorgeo.py 6 0:00:23.557451

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr 0:00:02.299767

Started | 2025-09-29 09:52:30
Ended | 2025-09-29 09:52:32
Duration | 0:00:02.299767
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/09/29 09:52:30:   Reading metadata for VNIR detector...
    2025/09/29 09:52:30:   Calculating solar irradiance...
    2025/09/29 09:52:30:   Reading metadata for SWIR detector...
    2025/09/29 09:52:31:   Calculating solar irradiance...
    2025/09/29 09:52:31:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:52:31:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:52:31:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:52:31:   Computing VNIR geolayer...
    2025/09/29 09:52:31:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/09/29 09:52:30:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

#### Call

##### Captured stdout call

    2025/09/29 09:52:32:   Transforming the 'mask_snow' attribute from VNIR to SWIR sensor geometry.

##### Captured stderr call

    2025/09/29 09:52:32:   The mask_snow is not yet available in SWIR sensor geometry. Use EnMAP_SWIR_SensorGeo.transform_vnir_to_swir_raster() to set it with a transformed version of the one provided in VNIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr__attrIsNone 0:00:00.005887

Started | 2025-09-29 09:52:32
Ended | 2025-09-29 09:52:32
Duration | 0:00:00.005887
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:52:32:   Transforming the 'mask_haze' attribute from VNIR to SWIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster__no_geolayer 0:00:00.010162

Started | 2025-09-29 09:52:32
Ended | 2025-09-29 09:52:32
Duration | 0:00:00.010162
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster_no_keystone 0:00:01.897126

Started | 2025-09-29 09:52:32
Ended | 2025-09-29 09:52:34
Duration | 0:00:01.897126
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster__no_geolayer 0:00:00.001278

Started | 2025-09-29 09:52:34
Ended | 2025-09-29 09:52:34
Duration | 0:00:00.001278
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster_with_keystone 0:00:19.343231

Started | 2025-09-29 09:52:34
Ended | 2025-09-29 09:52:53
Duration | 0:00:19.343231
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_isofit_enmap.py 65 0:02:02.944022

### PASSED Test_ISOFIT_EnMAP::test__compute_cos_i 0:00:09.622806

Started | 2025-09-29 09:52:53
Ended | 2025-09-29 09:53:03
Duration | 0:00:09.622806
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:52:53:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/29 09:52:53:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/29 09:52:54:   LUT zipfile already downloaded. Proceeding.
    2025/09/29 09:52:54:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Pulling release v1.0.3
    Downloading file
    Unzipping /root/.isofit/isofit-data.zip
    Done, now available at: /root/.isofit/data
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Pulling release v1.2.10
    Downloading file
    Unzipping /root/.isofit/isofit-tutorials.zip
    Downloading NEON data for the example
    Output as: /root/.isofit/examples/isotuts/NEON/data
    Downloading file
    Unzipping /root/.isofit/examples/isotuts/NEON/NEON-subset-data.zip
    Done, now available at: /root/.isofit/examples
    [!] Be sure to build the examples for your system via `isofit build`

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__compute_solar_phase 0:00:00.465198

Started | 2025-09-29 09:53:03
Ended | 2025-09-29 09:53:03
Duration | 0:00:00.465198
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:53:03:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/29 09:53:03:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/29 09:53:03:   LUT zipfile already downloaded. Proceeding.
    2025/09/29 09:53:03:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_6s 0:00:00.001138

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-09-29 09:53:03
Ended | 2025-09-29 09:53:03
Duration | 0:00:00.001138
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 185, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_lut_mod5 0:01:17.276870

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-09-29 09:53:03
Ended | 2025-09-29 09:54:21
Duration | 0:01:17.276870
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:53:03:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/29 09:53:03:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/29 09:53:04:   LUT zipfile already downloaded. Proceeding.
    2025/09/29 09:53:04:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/09/29 09:53:04:   Generating LUT file...
    2025/09/29 09:53:16:   Flightline ID: 20220717T110603Z
    2025/09/29 09:53:16:   no noise path found, proceeding without
    2025/09/29 09:53:16:   Running ISOFIT...
    2025/09/29 09:53:16:   Loading config file: /tmp/tmp_qh9w4zn/workdir/config/isofit_config.json
    2025/09/29 09:53:16:   Checking config sections for configuration issues
    2025/09/29 09:53:16:   Configuration file checks complete, no errors found.
    2025/09/29 09:53:27:   Building first forward model, will generate any necessary LUTs
    2025/09/29 09:53:27:   Loading from wavelength_file: /tmp/tmp_qh9w4zn/extracted/backtransformed_l2_spectra_v9/enmap_wavelengths.txt
    2025/09/29 09:53:27:   Prebuilt LUT provided
    2025/09/29 09:53:36:   Loading LUT into memory
    2025/09/29 09:53:36:   LUT grid loaded from file: OrderedDict({'AERFRAC_2': [0.05, 0.12, 0.2, 0.3, 0.4, 0.8], 'H2OSTR': [0.0, 1.0, 1.5, 2.0, 2.7, 3.5, 5.0], 'observer_zenith': [0, 10.0, 20.0, 30.0, 40.0], 'relative_azimuth': [0, 25.0, 50.0, 85.0, 120.0, 155.0, 180.0], 'solar_zenith': [0, 10.0, 20.0, 35.0, 50.0, 70.0], 'surface_elevation_km': [0, 0.7, 2.5, 8.0]})
    2025/09/29 09:53:57:   Beginning 100 inversions in 100 chunks using 20 cores
    2025/09/29 09:54:18:   Inversions complete.  21.24s total, 4.7076 spectra/s, 0.2354 spectra/s/core
    2025/09/29 09:54:19:   ISOFIT finished.
    2025/09/29 09:54:19:   Stopping ray.

##### Captured stderr call

    2025/09/29 09:53:16:
    ******************************************************************************************
    ! Number of threads is greater than 1 (currently: 24), this may greatly impact performance
    ! Please set this the environment variables 'MKL_NUM_THREADS' and 'OMP_NUM_THREADS' to '1'
    ******************************************************************************************
    2025-09-29 09:53:22,574	WARNING services.py:2070 -- WARNING: The object store is using /tmp instead of /dev/shm because /dev/shm has only 66887680 bytes available. This will harm performance! You may be able to free up space by deleting files in /dev/shm. If you are inside a Docker container, you can increase /dev/shm size by passing '--shm-size=10.24gb' to 'docker run' (or add it to the run_options list in a Ray cluster config). Make sure to set this to more than 30% of available RAM.
    2025-09-29 09:53:23,817	INFO worker.py:1852 -- Started a local Ray instance.
    WARNING: All log messages before absl::InitializeLog() is called are written to STDERR
    I0000 00:00:1759139659.668475     882 chttp2_transport.cc:1182] ipv4:172.17.0.13:54832: Got goaway [2] err=UNAVAILABLE:GOAWAY received; Error code: 2; Debug Text: Cancelling all calls {created_time:"2025-09-29T09:54:19.668455804+00:00", http2_error:2, grpc_status:14}

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe__direct_call 0:00:00.000638

Started | 2025-09-29 09:54:21
Ended | 2025-09-29 09:54:21
Duration | 0:00:00.000638
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 120, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe_on_map_geometry 0:00:00.000481

Started | 2025-09-29 09:54:21
Ended | 2025-09-29 09:54:21
Duration | 0:00:00.000481
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 154, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_download_isofit_resources 0:00:02.402014

Started | 2025-09-29 09:54:21
Ended | 2025-09-29 09:54:23
Duration | 0:00:02.402014
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:54:21:   ISOFIT surface spectra zipfile successfully downloaded.
    2025/09/29 09:54:23:   LUT zipfile successfully downloaded.
    2025/09/29 09:54:23:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/29 09:54:23:   LUT zipfile already downloaded. Proceeding.

##### Captured log call

    INFO     test_downloads:_isofit_downloads.py:83 ISOFIT surface spectra zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:83 LUT zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:87 ISOFIT surface spectra zipfile already downloaded. Proceeding.
    INFO     test_downloads:_isofit_downloads.py:87 LUT zipfile already downloaded. Proceeding.

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_generate_input_files 0:00:22.838636

Started | 2025-09-29 09:54:23
Ended | 2025-09-29 09:54:46
Duration | 0:00:22.838636
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:54:23:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/29 09:54:23:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/29 09:54:23:   LUT zipfile already downloaded. Proceeding.
    2025/09/29 09:54:23:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/09/29 09:54:23:   Reading Input Data
    2025/09/29 09:54:24:   Reading metadata for VNIR detector...
    2025/09/29 09:54:24:   Calculating solar irradiance...
    2025/09/29 09:54:24:   Reading metadata for SWIR detector...
    2025/09/29 09:54:24:   Calculating solar irradiance...
    2025/09/29 09:54:24:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:54:25:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:54:25:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:54:25:   Computing VNIR geolayer...
    2025/09/29 09:54:25:   Computing SWIR geolayer...
    2025/09/29 09:54:25:   Starting orthorectification...
    2025/09/29 09:54:25:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/09/29 09:54:25:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:54:26:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:54:27:   Merging VNIR and SWIR data...
    2025/09/29 09:54:27:   Orthorectifying 'mask_landwater' attribute...
    2025/09/29 09:54:28:   Orthorectifying 'mask_clouds' attribute...
    2025/09/29 09:54:28:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/29 09:54:28:   Orthorectifying 'mask_haze' attribute...
    2025/09/29 09:54:28:   Orthorectifying 'mask_snow' attribute...
    2025/09/29 09:54:29:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/29 09:54:29:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/29 09:54:29:   Generating L2A metadata...
    2025/09/29 09:54:30:   Generating radiance file...
    Writing GeoArray of size (290, 973, 202) to /tmp/tmpg8p_r0ij/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_rdn.
    2025/09/29 09:54:31:   Generating location file...
    2025/09/29 09:54:31:   Pre-processing DEM in map geometry...
    Automatically detected nodata value for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER': 0.0
    Writing GeoArray of size (290, 973, 3) to /tmp/tmpg8p_r0ij/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_loc.
    2025/09/29 09:54:31:   Generating observation file...
    Writing GeoArray of size (290, 973, 11) to /tmp/tmpg8p_r0ij/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_obs.
    2025/09/29 09:54:32:   Generating wavelength file...
    2025/09/29 09:54:32:   Generating surface file for default set of surface coverage types...
    0 ['filtered_other']
    0 ['filtered_veg']
    0 ['filtered_ocean']
    0 ['surface_Liquids']
    1 ['surface_Liquids']
    2025/09/29 09:54:35:   Generating LUT file...

##### Captured stderr call

    2025/09/29 09:54:24:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.1% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.0% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.0% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.1% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.0% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.0% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.1% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.0% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.0% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.0% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.1% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.1% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.0% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.1% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.0% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.0% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.0% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.0% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.7% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.2% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.0% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.0% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.0% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.0% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.2% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.0% Complete  => 0:00:00
    Warping progress     |============================================------| 87.1% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.1% Complete  => 0:00:00
    Warping progress     |================================================--| 95.0% Complete  => 0:00:00
    Warping progress     |================================================--| 96.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.0% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry 0:00:00.000557

Started | 2025-09-29 09:54:46
Ended | 2025-09-29 09:54:46
Duration | 0:00:00.000557
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 213, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry_no_segmentation 0:00:00.000666

Started | 2025-09-29 09:54:46
Ended | 2025-09-29 09:54:46
Duration | 0:00:00.000666
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 217, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_LUTTransformer::test_modtran_lut_to_netcdf 0:00:10.335017

Started | 2025-09-29 09:54:46
Ended | 2025-09-29 09:54:56
Duration | 0:00:10.335017
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_l1b_reader.py 10 0:01:48.778413

### PASSED Test_L1B_Reader::test_append_100_lines 0:00:18.842556

Started | 2025-09-29 09:54:56
Ended | 2025-09-29 09:55:15
Duration | 0:00:18.842556
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:54:57:   Reading Input Data
    2025/09/29 09:54:57:   Reading metadata for VNIR detector...
    2025/09/29 09:54:57:   Calculating solar irradiance...
    2025/09/29 09:54:57:   Reading metadata for SWIR detector...
    2025/09/29 09:54:57:   Calculating solar irradiance...
    2025/09/29 09:54:57:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:54:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:54:58:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:54:58:   Reading metadata for VNIR detector...
    2025/09/29 09:54:58:   Calculating solar irradiance...
    2025/09/29 09:54:58:   Reading metadata for SWIR detector...
    2025/09/29 09:54:58:   Calculating solar irradiance...
    2025/09/29 09:54:58:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:54:58:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:54:58:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:54:58:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:54:58:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:54:58:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:54:58:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:54:59:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy_i6cr1l/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy_i6cr1l/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy_i6cr1l/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy_i6cr1l/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy_i6cr1l/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy_i6cr1l/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy_i6cr1l/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpy_i6cr1l/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:54:59:   L1B product successfully written!
    2025/09/29 09:54:59:   Reading Input Data
    2025/09/29 09:54:59:   Reading metadata for VNIR detector...
    2025/09/29 09:54:59:   Calculating solar irradiance...
    2025/09/29 09:54:59:   Reading metadata for SWIR detector...
    2025/09/29 09:55:00:   Calculating solar irradiance...
    2025/09/29 09:55:00:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:00:   Reading Input Data
    2025/09/29 09:55:00:   Reading metadata for VNIR detector...
    2025/09/29 09:55:00:   Calculating solar irradiance...
    2025/09/29 09:55:00:   Reading metadata for SWIR detector...
    2025/09/29 09:55:00:   Calculating solar irradiance...
    2025/09/29 09:55:00:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:00:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:00:   Reading metadata for VNIR detector...
    2025/09/29 09:55:01:   Calculating solar irradiance...
    2025/09/29 09:55:01:   Reading metadata for SWIR detector...
    2025/09/29 09:55:01:   Calculating solar irradiance...
    2025/09/29 09:55:01:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:01:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:01:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:01:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:01:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:01:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:01:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:01:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:03:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:03:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp15zxklav/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp15zxklav/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp15zxklav/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp15zxklav/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp15zxklav/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp15zxklav/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp15zxklav/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp15zxklav/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:55:03:   L1B product successfully written!
    2025/09/29 09:55:03:   Reading Input Data
    2025/09/29 09:55:03:   Reading metadata for VNIR detector...
    2025/09/29 09:55:04:   Calculating solar irradiance...
    2025/09/29 09:55:04:   Reading metadata for SWIR detector...
    2025/09/29 09:55:04:   Calculating solar irradiance...
    2025/09/29 09:55:04:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:05:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:07:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:07:   Reading Input Data
    2025/09/29 09:55:07:   Reading metadata for VNIR detector...
    2025/09/29 09:55:08:   Calculating solar irradiance...
    2025/09/29 09:55:08:   Reading metadata for SWIR detector...
    2025/09/29 09:55:08:   Calculating solar irradiance...
    2025/09/29 09:55:08:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:09:   Reading metadata for VNIR detector...
    2025/09/29 09:55:09:   Calculating solar irradiance...
    2025/09/29 09:55:09:   Reading metadata for SWIR detector...
    2025/09/29 09:55:09:   Calculating solar irradiance...
    2025/09/29 09:55:09:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:09:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:10:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:10:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:10:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:10:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppquc3ket/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppquc3ket/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppquc3ket/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppquc3ket/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppquc3ket/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppquc3ket/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppquc3ket/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmppquc3ket/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:55:10:   L1B product successfully written!
    2025/09/29 09:55:10:   Reading Input Data
    2025/09/29 09:55:10:   Reading metadata for VNIR detector...
    2025/09/29 09:55:10:   Calculating solar irradiance...
    2025/09/29 09:55:10:   Reading metadata for SWIR detector...
    2025/09/29 09:55:11:   Calculating solar irradiance...
    2025/09/29 09:55:11:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:11:   Reading Input Data
    2025/09/29 09:55:11:   Reading metadata for VNIR detector...
    2025/09/29 09:55:11:   Calculating solar irradiance...
    2025/09/29 09:55:11:   Reading metadata for SWIR detector...
    2025/09/29 09:55:11:   Calculating solar irradiance...
    2025/09/29 09:55:11:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:11:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:11:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:12:   Reading metadata for VNIR detector...
    2025/09/29 09:55:12:   Calculating solar irradiance...
    2025/09/29 09:55:12:   Reading metadata for SWIR detector...
    2025/09/29 09:55:12:   Calculating solar irradiance...
    2025/09/29 09:55:12:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:12:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:12:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:12:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:12:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:12:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:13:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:13:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwgxlkfug/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwgxlkfug/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwgxlkfug/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwgxlkfug/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwgxlkfug/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwgxlkfug/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwgxlkfug/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwgxlkfug/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:55:13:   L1B product successfully written!
    2025/09/29 09:55:13:   Reading Input Data
    2025/09/29 09:55:13:   Reading metadata for VNIR detector...
    2025/09/29 09:55:14:   Calculating solar irradiance...
    2025/09/29 09:55:14:   Reading metadata for SWIR detector...
    2025/09/29 09:55:14:   Calculating solar irradiance...
    2025/09/29 09:55:14:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:14:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:15:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/29 09:54:58:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:54:58:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:54:58:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:54:58:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:54:58:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:54:59:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:54:59:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:54:59:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:54:59:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:54:59:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:01:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:55:01:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:55:01:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:55:01:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:55:01:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:55:03:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:03:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:03:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:03:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:03:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:10:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:10:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:10:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:10:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:10:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:10:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:10:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:12:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:12:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:13:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:13:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:13:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:13:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:13:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_10_lines 0:00:15.178288

Started | 2025-09-29 09:55:15
Ended | 2025-09-29 09:55:30
Duration | 0:00:15.178288
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:55:16:   Reading Input Data
    2025/09/29 09:55:16:   Reading metadata for VNIR detector...
    2025/09/29 09:55:16:   Calculating solar irradiance...
    2025/09/29 09:55:16:   Reading metadata for SWIR detector...
    2025/09/29 09:55:16:   Calculating solar irradiance...
    2025/09/29 09:55:16:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:17:   Reading metadata for VNIR detector...
    2025/09/29 09:55:17:   Calculating solar irradiance...
    2025/09/29 09:55:17:   Reading metadata for SWIR detector...
    2025/09/29 09:55:17:   Calculating solar irradiance...
    2025/09/29 09:55:17:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:17:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:17:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:17:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:17:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:17:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:17:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:17:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmirb65jf/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmirb65jf/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmirb65jf/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmirb65jf/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmirb65jf/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmirb65jf/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmirb65jf/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmirb65jf/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:55:18:   L1B product successfully written!
    2025/09/29 09:55:18:   Reading Input Data
    2025/09/29 09:55:18:   Reading metadata for VNIR detector...
    2025/09/29 09:55:18:   Calculating solar irradiance...
    2025/09/29 09:55:18:   Reading metadata for SWIR detector...
    2025/09/29 09:55:18:   Calculating solar irradiance...
    2025/09/29 09:55:18:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:18:   Reading Input Data
    2025/09/29 09:55:18:   Reading metadata for VNIR detector...
    2025/09/29 09:55:18:   Calculating solar irradiance...
    2025/09/29 09:55:19:   Reading metadata for SWIR detector...
    2025/09/29 09:55:19:   Calculating solar irradiance...
    2025/09/29 09:55:19:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:19:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:19:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:19:   Reading metadata for VNIR detector...
    2025/09/29 09:55:19:   Calculating solar irradiance...
    2025/09/29 09:55:19:   Reading metadata for SWIR detector...
    2025/09/29 09:55:20:   Calculating solar irradiance...
    2025/09/29 09:55:20:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:20:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:20:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:20:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:20:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:20:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:20:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:20:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:21:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:21:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa2a484r0/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa2a484r0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa2a484r0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa2a484r0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa2a484r0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa2a484r0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa2a484r0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa2a484r0/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:55:22:   L1B product successfully written!
    2025/09/29 09:55:22:   Reading Input Data
    2025/09/29 09:55:22:   Reading metadata for VNIR detector...
    2025/09/29 09:55:22:   Calculating solar irradiance...
    2025/09/29 09:55:22:   Reading metadata for SWIR detector...
    2025/09/29 09:55:22:   Calculating solar irradiance...
    2025/09/29 09:55:22:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:22:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:23:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:23:   Reading Input Data
    2025/09/29 09:55:24:   Reading metadata for VNIR detector...
    2025/09/29 09:55:24:   Calculating solar irradiance...
    2025/09/29 09:55:24:   Reading metadata for SWIR detector...
    2025/09/29 09:55:24:   Calculating solar irradiance...
    2025/09/29 09:55:24:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:24:   Reading metadata for VNIR detector...
    2025/09/29 09:55:24:   Calculating solar irradiance...
    2025/09/29 09:55:24:   Reading metadata for SWIR detector...
    2025/09/29 09:55:25:   Calculating solar irradiance...
    2025/09/29 09:55:25:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:25:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:25:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:25:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:25:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:25:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjb16g0ut/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjb16g0ut/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjb16g0ut/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjb16g0ut/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjb16g0ut/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjb16g0ut/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjb16g0ut/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpjb16g0ut/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:55:25:   L1B product successfully written!
    2025/09/29 09:55:25:   Reading Input Data
    2025/09/29 09:55:25:   Reading metadata for VNIR detector...
    2025/09/29 09:55:25:   Calculating solar irradiance...
    2025/09/29 09:55:25:   Reading metadata for SWIR detector...
    2025/09/29 09:55:26:   Calculating solar irradiance...
    2025/09/29 09:55:26:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:26:   Reading Input Data
    2025/09/29 09:55:26:   Reading metadata for VNIR detector...
    2025/09/29 09:55:26:   Calculating solar irradiance...
    2025/09/29 09:55:26:   Reading metadata for SWIR detector...
    2025/09/29 09:55:26:   Calculating solar irradiance...
    2025/09/29 09:55:26:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:26:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:26:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:27:   Reading metadata for VNIR detector...
    2025/09/29 09:55:27:   Calculating solar irradiance...
    2025/09/29 09:55:27:   Reading metadata for SWIR detector...
    2025/09/29 09:55:27:   Calculating solar irradiance...
    2025/09/29 09:55:27:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:27:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:27:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:27:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:27:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:27:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:28:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:28:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb21e4ayo/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb21e4ayo/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb21e4ayo/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb21e4ayo/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb21e4ayo/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb21e4ayo/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb21e4ayo/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb21e4ayo/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:55:29:   L1B product successfully written!
    2025/09/29 09:55:29:   Reading Input Data
    2025/09/29 09:55:29:   Reading metadata for VNIR detector...
    2025/09/29 09:55:29:   Calculating solar irradiance...
    2025/09/29 09:55:29:   Reading metadata for SWIR detector...
    2025/09/29 09:55:29:   Calculating solar irradiance...
    2025/09/29 09:55:29:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:29:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:30:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/29 09:55:17:   A minimum of 50 lines is required, only 10 were selected
    2025/09/29 09:55:17:   Set the number of line to 50
    2025/09/29 09:55:17:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:55:17:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:55:17:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:55:17:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:55:17:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:55:17:   A minimum of 50 lines is required, only 10 were selected
    2025/09/29 09:55:17:   Set the number of line to 50
    2025/09/29 09:55:17:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:17:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:17:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:17:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:17:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:20:   A minimum of 50 lines is required, only 10 were selected
    2025/09/29 09:55:20:   Set the number of line to 50
    2025/09/29 09:55:20:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:55:20:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:55:20:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:55:20:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:55:20:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:55:20:   A minimum of 50 lines is required, only 10 were selected
    2025/09/29 09:55:20:   Set the number of line to 50
    2025/09/29 09:55:21:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:21:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:21:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:21:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:21:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:25:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:25:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:25:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:25:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:25:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:25:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:25:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:27:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:27:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:28:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:28:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:28:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:28:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:28:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_150_lines 0:00:16.036654

Started | 2025-09-29 09:55:30
Ended | 2025-09-29 09:55:46
Duration | 0:00:16.036654
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:55:31:   Reading Input Data
    2025/09/29 09:55:31:   Reading metadata for VNIR detector...
    2025/09/29 09:55:31:   Calculating solar irradiance...
    2025/09/29 09:55:31:   Reading metadata for SWIR detector...
    2025/09/29 09:55:31:   Calculating solar irradiance...
    2025/09/29 09:55:31:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:31:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:32:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:32:   Reading metadata for VNIR detector...
    2025/09/29 09:55:32:   Calculating solar irradiance...
    2025/09/29 09:55:32:   Reading metadata for SWIR detector...
    2025/09/29 09:55:32:   Calculating solar irradiance...
    2025/09/29 09:55:32:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:32:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:32:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:32:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:33:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:33:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:33:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:33:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvkl_o4kw/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvkl_o4kw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvkl_o4kw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvkl_o4kw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvkl_o4kw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvkl_o4kw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvkl_o4kw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvkl_o4kw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:55:33:   L1B product successfully written!
    2025/09/29 09:55:33:   Reading Input Data
    2025/09/29 09:55:33:   Reading metadata for VNIR detector...
    2025/09/29 09:55:33:   Calculating solar irradiance...
    2025/09/29 09:55:33:   Reading metadata for SWIR detector...
    2025/09/29 09:55:34:   Calculating solar irradiance...
    2025/09/29 09:55:34:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:34:   Reading Input Data
    2025/09/29 09:55:34:   Reading metadata for VNIR detector...
    2025/09/29 09:55:34:   Calculating solar irradiance...
    2025/09/29 09:55:34:   Reading metadata for SWIR detector...
    2025/09/29 09:55:34:   Calculating solar irradiance...
    2025/09/29 09:55:34:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:34:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:34:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:34:   Reading metadata for VNIR detector...
    2025/09/29 09:55:35:   Calculating solar irradiance...
    2025/09/29 09:55:35:   Reading metadata for SWIR detector...
    2025/09/29 09:55:35:   Calculating solar irradiance...
    2025/09/29 09:55:35:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:35:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:35:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:35:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:35:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:35:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:35:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:35:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:37:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:37:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8taceemr/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8taceemr/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8taceemr/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8taceemr/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8taceemr/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8taceemr/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8taceemr/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8taceemr/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:55:37:   L1B product successfully written!
    2025/09/29 09:55:37:   Reading Input Data
    2025/09/29 09:55:37:   Reading metadata for VNIR detector...
    2025/09/29 09:55:38:   Calculating solar irradiance...
    2025/09/29 09:55:38:   Reading metadata for SWIR detector...
    2025/09/29 09:55:38:   Calculating solar irradiance...
    2025/09/29 09:55:38:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:38:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:40:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:40:   Reading Input Data
    2025/09/29 09:55:40:   Reading metadata for VNIR detector...
    2025/09/29 09:55:40:   Calculating solar irradiance...
    2025/09/29 09:55:40:   Reading metadata for SWIR detector...
    2025/09/29 09:55:40:   Calculating solar irradiance...
    2025/09/29 09:55:40:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:40:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:40:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:41:   Reading metadata for VNIR detector...
    2025/09/29 09:55:41:   Calculating solar irradiance...
    2025/09/29 09:55:41:   Reading metadata for SWIR detector...
    2025/09/29 09:55:41:   Calculating solar irradiance...
    2025/09/29 09:55:41:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:41:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:41:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:41:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:41:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:41:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwnc22k55/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwnc22k55/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwnc22k55/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwnc22k55/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwnc22k55/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwnc22k55/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwnc22k55/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpwnc22k55/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:55:42:   L1B product successfully written!
    2025/09/29 09:55:42:   Reading Input Data
    2025/09/29 09:55:42:   Reading metadata for VNIR detector...
    2025/09/29 09:55:42:   Calculating solar irradiance...
    2025/09/29 09:55:42:   Reading metadata for SWIR detector...
    2025/09/29 09:55:42:   Calculating solar irradiance...
    2025/09/29 09:55:42:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:42:   Reading Input Data
    2025/09/29 09:55:42:   Reading metadata for VNIR detector...
    2025/09/29 09:55:42:   Calculating solar irradiance...
    2025/09/29 09:55:42:   Reading metadata for SWIR detector...
    2025/09/29 09:55:43:   Calculating solar irradiance...
    2025/09/29 09:55:43:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:43:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:43:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:43:   Reading metadata for VNIR detector...
    2025/09/29 09:55:43:   Calculating solar irradiance...
    2025/09/29 09:55:43:   Reading metadata for SWIR detector...
    2025/09/29 09:55:43:   Calculating solar irradiance...
    2025/09/29 09:55:44:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:44:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:44:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:44:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:44:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:44:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:44:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:45:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_lgxo3x/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_lgxo3x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_lgxo3x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_lgxo3x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_lgxo3x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_lgxo3x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_lgxo3x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt_lgxo3x/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:55:45:   L1B product successfully written!
    2025/09/29 09:55:45:   Reading Input Data
    2025/09/29 09:55:45:   Reading metadata for VNIR detector...
    2025/09/29 09:55:45:   Calculating solar irradiance...
    2025/09/29 09:55:45:   Reading metadata for SWIR detector...
    2025/09/29 09:55:45:   Calculating solar irradiance...
    2025/09/29 09:55:45:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:45:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:46:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/29 09:55:33:   n_lines (150) exceeds the total number of line of second image
    2025/09/29 09:55:33:   Set to the image number of line
    2025/09/29 09:55:33:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:55:33:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:55:33:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:55:33:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:55:33:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:55:33:   n_lines (150) exceeds the total number of line of second image
    2025/09/29 09:55:33:   Set to the image number of line
    2025/09/29 09:55:33:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:33:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:33:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:33:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:33:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:35:   n_lines (150) exceeds the total number of line of second image
    2025/09/29 09:55:35:   Set to the image number of line
    2025/09/29 09:55:35:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:55:35:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:55:35:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:55:35:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:55:35:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:55:35:   n_lines (150) exceeds the total number of line of second image
    2025/09/29 09:55:35:   Set to the image number of line
    2025/09/29 09:55:37:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:37:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:37:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:37:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:37:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:41:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:41:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:41:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:41:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:41:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:41:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:41:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:44:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:44:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:45:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:45:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:45:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:45:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:45:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_50_lines 0:00:14.684770

Started | 2025-09-29 09:55:46
Ended | 2025-09-29 09:56:01
Duration | 0:00:14.684770
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:55:47:   Reading Input Data
    2025/09/29 09:55:47:   Reading metadata for VNIR detector...
    2025/09/29 09:55:47:   Calculating solar irradiance...
    2025/09/29 09:55:47:   Reading metadata for SWIR detector...
    2025/09/29 09:55:47:   Calculating solar irradiance...
    2025/09/29 09:55:47:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:47:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:48:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:48:   Reading metadata for VNIR detector...
    2025/09/29 09:55:48:   Calculating solar irradiance...
    2025/09/29 09:55:48:   Reading metadata for SWIR detector...
    2025/09/29 09:55:48:   Calculating solar irradiance...
    2025/09/29 09:55:48:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:48:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:48:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:48:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:48:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:48:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:48:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:49:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8tomun93/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8tomun93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8tomun93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8tomun93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8tomun93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8tomun93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8tomun93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8tomun93/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:55:49:   L1B product successfully written!
    2025/09/29 09:55:49:   Reading Input Data
    2025/09/29 09:55:49:   Reading metadata for VNIR detector...
    2025/09/29 09:55:49:   Calculating solar irradiance...
    2025/09/29 09:55:49:   Reading metadata for SWIR detector...
    2025/09/29 09:55:49:   Calculating solar irradiance...
    2025/09/29 09:55:49:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:49:   Reading Input Data
    2025/09/29 09:55:49:   Reading metadata for VNIR detector...
    2025/09/29 09:55:50:   Calculating solar irradiance...
    2025/09/29 09:55:50:   Reading metadata for SWIR detector...
    2025/09/29 09:55:50:   Calculating solar irradiance...
    2025/09/29 09:55:50:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:50:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:50:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:50:   Reading metadata for VNIR detector...
    2025/09/29 09:55:50:   Calculating solar irradiance...
    2025/09/29 09:55:50:   Reading metadata for SWIR detector...
    2025/09/29 09:55:51:   Calculating solar irradiance...
    2025/09/29 09:55:51:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:51:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:51:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:51:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:51:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:51:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:55:51:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:52:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:52:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv5exliw1/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv5exliw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv5exliw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv5exliw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv5exliw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv5exliw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv5exliw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpv5exliw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:55:53:   L1B product successfully written!
    2025/09/29 09:55:53:   Reading Input Data
    2025/09/29 09:55:53:   Reading metadata for VNIR detector...
    2025/09/29 09:55:53:   Calculating solar irradiance...
    2025/09/29 09:55:53:   Reading metadata for SWIR detector...
    2025/09/29 09:55:53:   Calculating solar irradiance...
    2025/09/29 09:55:53:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:53:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:54:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:54:   Reading Input Data
    2025/09/29 09:55:54:   Reading metadata for VNIR detector...
    2025/09/29 09:55:55:   Calculating solar irradiance...
    2025/09/29 09:55:55:   Reading metadata for SWIR detector...
    2025/09/29 09:55:55:   Calculating solar irradiance...
    2025/09/29 09:55:55:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:55:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:55:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:55:   Reading metadata for VNIR detector...
    2025/09/29 09:55:55:   Calculating solar irradiance...
    2025/09/29 09:55:55:   Reading metadata for SWIR detector...
    2025/09/29 09:55:56:   Calculating solar irradiance...
    2025/09/29 09:55:56:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:56:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:56:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:56:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:56:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvpmnm43j/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvpmnm43j/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvpmnm43j/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvpmnm43j/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvpmnm43j/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvpmnm43j/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvpmnm43j/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvpmnm43j/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:55:56:   L1B product successfully written!
    2025/09/29 09:55:56:   Reading Input Data
    2025/09/29 09:55:56:   Reading metadata for VNIR detector...
    2025/09/29 09:55:56:   Calculating solar irradiance...
    2025/09/29 09:55:56:   Reading metadata for SWIR detector...
    2025/09/29 09:55:57:   Calculating solar irradiance...
    2025/09/29 09:55:57:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:57:   Reading Input Data
    2025/09/29 09:55:57:   Reading metadata for VNIR detector...
    2025/09/29 09:55:57:   Calculating solar irradiance...
    2025/09/29 09:55:57:   Reading metadata for SWIR detector...
    2025/09/29 09:55:57:   Calculating solar irradiance...
    2025/09/29 09:55:57:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:58:   Reading metadata for VNIR detector...
    2025/09/29 09:55:58:   Calculating solar irradiance...
    2025/09/29 09:55:58:   Reading metadata for SWIR detector...
    2025/09/29 09:55:58:   Calculating solar irradiance...
    2025/09/29 09:55:58:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:55:58:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:55:58:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:55:58:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:58:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:55:58:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:55:59:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:55:59:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqs_6hecv/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqs_6hecv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqs_6hecv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqs_6hecv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqs_6hecv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqs_6hecv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqs_6hecv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqs_6hecv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:55:59:   L1B product successfully written!
    2025/09/29 09:55:59:   Reading Input Data
    2025/09/29 09:55:59:   Reading metadata for VNIR detector...
    2025/09/29 09:56:00:   Calculating solar irradiance...
    2025/09/29 09:56:00:   Reading metadata for SWIR detector...
    2025/09/29 09:56:00:   Calculating solar irradiance...
    2025/09/29 09:56:00:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:00:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:56:01:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/29 09:55:48:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:55:48:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:55:48:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:55:48:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:55:48:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:55:49:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:49:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:49:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:49:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:49:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:51:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:55:51:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:55:51:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:55:51:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:55:51:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:55:52:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:52:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:52:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:52:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:52:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:56:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:56:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:56:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:56:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:56:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:56:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:56:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:55:58:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:58:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:55:59:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:55:59:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:55:59:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:55:59:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:55:59:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_80_lines 0:00:18.309021

Started | 2025-09-29 09:56:01
Ended | 2025-09-29 09:56:19
Duration | 0:00:18.309021
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:56:02:   Reading Input Data
    2025/09/29 09:56:02:   Reading metadata for VNIR detector...
    2025/09/29 09:56:02:   Calculating solar irradiance...
    2025/09/29 09:56:02:   Reading metadata for SWIR detector...
    2025/09/29 09:56:02:   Calculating solar irradiance...
    2025/09/29 09:56:02:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:02:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:02:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:02:   Reading metadata for VNIR detector...
    2025/09/29 09:56:03:   Calculating solar irradiance...
    2025/09/29 09:56:03:   Reading metadata for SWIR detector...
    2025/09/29 09:56:03:   Calculating solar irradiance...
    2025/09/29 09:56:03:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:03:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:03:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:03:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:03:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:03:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:03:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:04:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1snwv682/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1snwv682/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1snwv682/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1snwv682/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1snwv682/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1snwv682/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1snwv682/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1snwv682/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:56:04:   L1B product successfully written!
    2025/09/29 09:56:04:   Reading Input Data
    2025/09/29 09:56:04:   Reading metadata for VNIR detector...
    2025/09/29 09:56:05:   Calculating solar irradiance...
    2025/09/29 09:56:05:   Reading metadata for SWIR detector...
    2025/09/29 09:56:05:   Calculating solar irradiance...
    2025/09/29 09:56:05:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:05:   Reading Input Data
    2025/09/29 09:56:05:   Reading metadata for VNIR detector...
    2025/09/29 09:56:05:   Calculating solar irradiance...
    2025/09/29 09:56:05:   Reading metadata for SWIR detector...
    2025/09/29 09:56:06:   Calculating solar irradiance...
    2025/09/29 09:56:06:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:06:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:06:   Reading metadata for VNIR detector...
    2025/09/29 09:56:07:   Calculating solar irradiance...
    2025/09/29 09:56:07:   Reading metadata for SWIR detector...
    2025/09/29 09:56:07:   Calculating solar irradiance...
    2025/09/29 09:56:07:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:07:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:07:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:08:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:08:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:08:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:08:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:08:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:56:10:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:56:10:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8gx2okqy/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8gx2okqy/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8gx2okqy/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8gx2okqy/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8gx2okqy/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8gx2okqy/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8gx2okqy/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8gx2okqy/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:56:10:   L1B product successfully written!
    2025/09/29 09:56:10:   Reading Input Data
    2025/09/29 09:56:10:   Reading metadata for VNIR detector...
    2025/09/29 09:56:11:   Calculating solar irradiance...
    2025/09/29 09:56:11:   Reading metadata for SWIR detector...
    2025/09/29 09:56:11:   Calculating solar irradiance...
    2025/09/29 09:56:11:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:11:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:56:13:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:56:13:   Reading Input Data
    2025/09/29 09:56:13:   Reading metadata for VNIR detector...
    2025/09/29 09:56:13:   Calculating solar irradiance...
    2025/09/29 09:56:13:   Reading metadata for SWIR detector...
    2025/09/29 09:56:13:   Calculating solar irradiance...
    2025/09/29 09:56:13:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:13:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:13:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:14:   Reading metadata for VNIR detector...
    2025/09/29 09:56:14:   Calculating solar irradiance...
    2025/09/29 09:56:14:   Reading metadata for SWIR detector...
    2025/09/29 09:56:14:   Calculating solar irradiance...
    2025/09/29 09:56:14:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:14:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:14:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:14:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:56:14:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:56:14:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqf5s2ura/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqf5s2ura/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqf5s2ura/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqf5s2ura/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqf5s2ura/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqf5s2ura/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqf5s2ura/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpqf5s2ura/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:56:15:   L1B product successfully written!
    2025/09/29 09:56:15:   Reading Input Data
    2025/09/29 09:56:15:   Reading metadata for VNIR detector...
    2025/09/29 09:56:15:   Calculating solar irradiance...
    2025/09/29 09:56:15:   Reading metadata for SWIR detector...
    2025/09/29 09:56:15:   Calculating solar irradiance...
    2025/09/29 09:56:15:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:15:   Reading Input Data
    2025/09/29 09:56:15:   Reading metadata for VNIR detector...
    2025/09/29 09:56:15:   Calculating solar irradiance...
    2025/09/29 09:56:15:   Reading metadata for SWIR detector...
    2025/09/29 09:56:16:   Calculating solar irradiance...
    2025/09/29 09:56:16:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:16:   Reading metadata for VNIR detector...
    2025/09/29 09:56:16:   Calculating solar irradiance...
    2025/09/29 09:56:16:   Reading metadata for SWIR detector...
    2025/09/29 09:56:16:   Calculating solar irradiance...
    2025/09/29 09:56:16:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:17:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:17:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:56:17:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:56:17:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:56:17:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:56:18:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm5rymboz/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm5rymboz/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm5rymboz/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm5rymboz/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm5rymboz/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm5rymboz/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm5rymboz/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpm5rymboz/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:56:18:   L1B product successfully written!
    2025/09/29 09:56:18:   Reading Input Data
    2025/09/29 09:56:18:   Reading metadata for VNIR detector...
    2025/09/29 09:56:18:   Calculating solar irradiance...
    2025/09/29 09:56:18:   Reading metadata for SWIR detector...
    2025/09/29 09:56:18:   Calculating solar irradiance...
    2025/09/29 09:56:18:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:18:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:56:19:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/29 09:56:03:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:56:03:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:56:03:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:56:03:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:56:03:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:56:04:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:56:04:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:56:04:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:56:04:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:56:04:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:56:08:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:56:08:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:56:08:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:56:08:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:56:08:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:56:10:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:56:10:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:56:10:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:56:10:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:56:10:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:56:14:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:56:14:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:56:14:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:56:14:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:56:14:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:56:14:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:56:14:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:56:17:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:56:17:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:56:18:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:56:18:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:56:18:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:56:18:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:56:18:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_all_lines 0:00:16.237517

Started | 2025-09-29 09:56:19
Ended | 2025-09-29 09:56:36
Duration | 0:00:16.237517
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:56:20:   Reading Input Data
    2025/09/29 09:56:20:   Reading metadata for VNIR detector...
    2025/09/29 09:56:20:   Calculating solar irradiance...
    2025/09/29 09:56:20:   Reading metadata for SWIR detector...
    2025/09/29 09:56:20:   Calculating solar irradiance...
    2025/09/29 09:56:21:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:21:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:21:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:21:   Reading metadata for VNIR detector...
    2025/09/29 09:56:21:   Calculating solar irradiance...
    2025/09/29 09:56:21:   Reading metadata for SWIR detector...
    2025/09/29 09:56:21:   Calculating solar irradiance...
    2025/09/29 09:56:21:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:21:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:21:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:22:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:22:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:22:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:22:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:22:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpiwfauckq/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpiwfauckq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpiwfauckq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpiwfauckq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpiwfauckq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpiwfauckq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpiwfauckq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpiwfauckq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:56:22:   L1B product successfully written!
    2025/09/29 09:56:22:   Reading Input Data
    2025/09/29 09:56:22:   Reading metadata for VNIR detector...
    2025/09/29 09:56:22:   Calculating solar irradiance...
    2025/09/29 09:56:22:   Reading metadata for SWIR detector...
    2025/09/29 09:56:23:   Calculating solar irradiance...
    2025/09/29 09:56:23:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:23:   Reading Input Data
    2025/09/29 09:56:23:   Reading metadata for VNIR detector...
    2025/09/29 09:56:23:   Calculating solar irradiance...
    2025/09/29 09:56:23:   Reading metadata for SWIR detector...
    2025/09/29 09:56:23:   Calculating solar irradiance...
    2025/09/29 09:56:23:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:23:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:23:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:23:   Reading metadata for VNIR detector...
    2025/09/29 09:56:24:   Calculating solar irradiance...
    2025/09/29 09:56:24:   Reading metadata for SWIR detector...
    2025/09/29 09:56:24:   Calculating solar irradiance...
    2025/09/29 09:56:24:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:24:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:24:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:24:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:24:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/29 09:56:24:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:56:26:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:56:26:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgbqalk8f/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgbqalk8f/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgbqalk8f/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgbqalk8f/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgbqalk8f/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgbqalk8f/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgbqalk8f/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgbqalk8f/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:56:26:   L1B product successfully written!
    2025/09/29 09:56:26:   Reading Input Data
    2025/09/29 09:56:26:   Reading metadata for VNIR detector...
    2025/09/29 09:56:27:   Calculating solar irradiance...
    2025/09/29 09:56:27:   Reading metadata for SWIR detector...
    2025/09/29 09:56:27:   Calculating solar irradiance...
    2025/09/29 09:56:27:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:27:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:56:29:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:56:29:   Reading Input Data
    2025/09/29 09:56:29:   Reading metadata for VNIR detector...
    2025/09/29 09:56:29:   Calculating solar irradiance...
    2025/09/29 09:56:29:   Reading metadata for SWIR detector...
    2025/09/29 09:56:29:   Calculating solar irradiance...
    2025/09/29 09:56:29:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:29:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:29:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:30:   Reading metadata for VNIR detector...
    2025/09/29 09:56:30:   Calculating solar irradiance...
    2025/09/29 09:56:30:   Reading metadata for SWIR detector...
    2025/09/29 09:56:30:   Calculating solar irradiance...
    2025/09/29 09:56:30:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:30:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:30:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:30:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:56:30:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:56:30:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6hoiwqz3/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6hoiwqz3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6hoiwqz3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6hoiwqz3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6hoiwqz3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6hoiwqz3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6hoiwqz3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6hoiwqz3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:56:31:   L1B product successfully written!
    2025/09/29 09:56:31:   Reading Input Data
    2025/09/29 09:56:31:   Reading metadata for VNIR detector...
    2025/09/29 09:56:31:   Calculating solar irradiance...
    2025/09/29 09:56:31:   Reading metadata for SWIR detector...
    2025/09/29 09:56:31:   Calculating solar irradiance...
    2025/09/29 09:56:31:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:31:   Reading Input Data
    2025/09/29 09:56:31:   Reading metadata for VNIR detector...
    2025/09/29 09:56:32:   Calculating solar irradiance...
    2025/09/29 09:56:32:   Reading metadata for SWIR detector...
    2025/09/29 09:56:32:   Calculating solar irradiance...
    2025/09/29 09:56:32:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:32:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:32:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:32:   Reading metadata for VNIR detector...
    2025/09/29 09:56:32:   Calculating solar irradiance...
    2025/09/29 09:56:32:   Reading metadata for SWIR detector...
    2025/09/29 09:56:33:   Calculating solar irradiance...
    2025/09/29 09:56:33:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:33:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:33:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:33:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:56:33:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/29 09:56:33:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:56:34:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:56:34:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6ai9wz3f/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6ai9wz3f/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6ai9wz3f/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6ai9wz3f/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6ai9wz3f/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6ai9wz3f/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6ai9wz3f/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6ai9wz3f/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/29 09:56:34:   L1B product successfully written!
    2025/09/29 09:56:34:   Reading Input Data
    2025/09/29 09:56:34:   Reading metadata for VNIR detector...
    2025/09/29 09:56:34:   Calculating solar irradiance...
    2025/09/29 09:56:34:   Reading metadata for SWIR detector...
    2025/09/29 09:56:35:   Calculating solar irradiance...
    2025/09/29 09:56:35:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:35:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:56:35:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/29 09:56:22:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:56:22:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:56:22:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:56:22:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:56:22:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:56:22:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:56:22:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:56:22:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:56:22:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:56:22:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:56:24:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/29 09:56:24:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/29 09:56:24:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/29 09:56:24:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/29 09:56:24:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/29 09:56:26:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:56:26:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:56:26:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:56:26:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:56:26:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:56:30:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:56:30:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:56:30:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:56:30:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:56:30:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:56:30:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:56:30:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/29 09:56:33:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:56:33:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/29 09:56:34:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:56:34:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:56:34:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:56:34:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:56:34:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_no_snr 0:00:02.385537

Test to read test image 1, save it and read the saved result again - without SNR.

Started | 2025-09-29 09:56:36
Ended | 2025-09-29 09:56:38
Duration | 0:00:02.385537
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:56:36:   Reading Input Data
    2025/09/29 09:56:36:   Reading metadata for VNIR detector...
    2025/09/29 09:56:36:   Calculating solar irradiance...
    2025/09/29 09:56:37:   Reading metadata for SWIR detector...
    2025/09/29 09:56:37:   Calculating solar irradiance...
    2025/09/29 09:56:37:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:37:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:37:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:37:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe4qegl2k/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe4qegl2k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe4qegl2k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe4qegl2k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe4qegl2k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe4qegl2k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe4qegl2k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpe4qegl2k/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:56:37:   L1B product successfully written!
    2025/09/29 09:56:37:   Reading Input Data
    2025/09/29 09:56:37:   Reading metadata for VNIR detector...
    2025/09/29 09:56:38:   Calculating solar irradiance...
    2025/09/29 09:56:38:   Reading metadata for SWIR detector...
    2025/09/29 09:56:38:   Calculating solar irradiance...
    2025/09/29 09:56:38:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/09/29 09:56:37:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:56:37:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:56:37:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:56:37:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:56:37:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_with_snr 0:00:02.983119

Test to read test image 1, save it and read the saved result again - with SNR.

Started | 2025-09-29 09:56:38
Ended | 2025-09-29 09:56:41
Duration | 0:00:02.983119
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:56:39:   Reading Input Data
    2025/09/29 09:56:39:   Reading metadata for VNIR detector...
    2025/09/29 09:56:39:   Calculating solar irradiance...
    2025/09/29 09:56:39:   Reading metadata for SWIR detector...
    2025/09/29 09:56:39:   Calculating solar irradiance...
    2025/09/29 09:56:39:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:39:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:39:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:39:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:56:40:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:56:40:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpku3_b01u/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpku3_b01u/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpku3_b01u/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpku3_b01u/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpku3_b01u/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpku3_b01u/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpku3_b01u/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpku3_b01u/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/29 09:56:40:   L1B product successfully written!
    2025/09/29 09:56:40:   Reading Input Data
    2025/09/29 09:56:40:   Reading metadata for VNIR detector...
    2025/09/29 09:56:41:   Calculating solar irradiance...
    2025/09/29 09:56:41:   Reading metadata for SWIR detector...
    2025/09/29 09:56:41:   Calculating solar irradiance...
    2025/09/29 09:56:41:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/09/29 09:56:40:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/29 09:56:40:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/29 09:56:40:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/29 09:56:40:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/29 09:56:40:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata 0:00:02.389602

Started | 2025-09-29 09:56:41
Ended | 2025-09-29 09:56:43
Duration | 0:00:02.389602
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:56:41:   Reading Input Data
    2025/09/29 09:56:41:   Reading metadata for VNIR detector...
    2025/09/29 09:56:41:   Calculating solar irradiance...
    2025/09/29 09:56:42:   Reading metadata for SWIR detector...
    2025/09/29 09:56:42:   Calculating solar irradiance...
    2025/09/29 09:56:42:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:42:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:42:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:43:   Computing VNIR geolayer...
    2025/09/29 09:56:43:   Computing SWIR geolayer...
    2025/09/29 09:56:43:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_VNIR.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_VNIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.png.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.png.
    2025/09/29 09:56:43:   L1B product successfully written!

##### Captured stderr call

    2025/09/29 09:56:41:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata_dont_drop_bad_bands 0:00:01.731349

Started | 2025-09-29 09:56:43
Ended | 2025-09-29 09:56:45
Duration | 0:00:01.731349
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:56:43:   Reading Input Data
    2025/09/29 09:56:44:   Reading metadata for VNIR detector...
    2025/09/29 09:56:44:   Calculating solar irradiance...
    2025/09/29 09:56:44:   Reading metadata for SWIR detector...
    2025/09/29 09:56:44:   Calculating solar irradiance...
    2025/09/29 09:56:44:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:44:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:44:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:45:   Computing VNIR geolayer...
    2025/09/29 09:56:45:   Computing SWIR geolayer...

##### Captured stderr call

    2025/09/29 09:56:43:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_orthorectification.py 10 0:00:26.536581

### PASSED Test_Orthorectifier::test_run_transformation_ll 0:00:05.163350

Started | 2025-09-29 09:56:45
Ended | 2025-09-29 09:56:50
Duration | 0:00:05.163350
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:56:45:   Reading Input Data
    2025/09/29 09:56:45:   Reading metadata for VNIR detector...
    2025/09/29 09:56:46:   Calculating solar irradiance...
    2025/09/29 09:56:46:   Reading metadata for SWIR detector...
    2025/09/29 09:56:46:   Calculating solar irradiance...
    2025/09/29 09:56:46:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:46:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:46:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:46:   Starting orthorectification...
    2025/09/29 09:56:46:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (10.691214991975885, 47.455058810417405, 11.070768, 47.540321)
    2025/09/29 09:56:46:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:56:47:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:56:48:   Merging VNIR and SWIR data...
    2025/09/29 09:56:48:   Orthorectifying 'mask_clouds' attribute...
    2025/09/29 09:56:49:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/29 09:56:49:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier::test_run_transformation_utm 0:00:05.178943

Started | 2025-09-29 09:56:50
Ended | 2025-09-29 09:56:55
Duration | 0:00:05.178943
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:56:51:   Reading Input Data
    2025/09/29 09:56:51:   Reading metadata for VNIR detector...
    2025/09/29 09:56:51:   Calculating solar irradiance...
    2025/09/29 09:56:51:   Reading metadata for SWIR detector...
    2025/09/29 09:56:51:   Calculating solar irradiance...
    2025/09/29 09:56:51:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:51:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:51:   Starting orthorectification...
    2025/09/29 09:56:51:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257770.0, 656040.0, 5266620.0)
    2025/09/29 09:56:51:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:56:52:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:56:54:   Merging VNIR and SWIR data...
    2025/09/29 09:56:54:   Orthorectifying 'mask_clouds' attribute...
    2025/09/29 09:56:54:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/29 09:56:55:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_ll 0:00:06.761064

Started | 2025-09-29 09:56:55
Ended | 2025-09-29 09:57:02
Duration | 0:00:06.761064
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:56:56:   Reading Input Data
    2025/09/29 09:56:56:   Reading metadata for VNIR detector...
    2025/09/29 09:56:56:   Calculating solar irradiance...
    2025/09/29 09:56:56:   Reading metadata for SWIR detector...
    2025/09/29 09:56:56:   Calculating solar irradiance...
    2025/09/29 09:56:56:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:56:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:56:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:56:57:   Computing VNIR geolayer...
    2025/09/29 09:56:57:   Computing SWIR geolayer...
    2025/09/29 09:56:57:   Starting orthorectification...
    2025/09/29 09:56:57:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (-1.2717290915354968, 44.60009471477741, -0.9054060033197534, 44.68406888113938)
    2025/09/29 09:56:57:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:56:58:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:56:59:   Merging VNIR and SWIR data...
    2025/09/29 09:56:59:   Orthorectifying 'mask_landwater' attribute...
    2025/09/29 09:57:00:   Orthorectifying 'mask_clouds' attribute...
    2025/09/29 09:57:00:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/29 09:57:00:   Orthorectifying 'mask_haze' attribute...
    2025/09/29 09:57:00:   Orthorectifying 'mask_snow' attribute...
    2025/09/29 09:57:00:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/29 09:57:01:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/29 09:57:01:   Generating L2A metadata...

##### Captured stderr call

    2025/09/29 09:56:56:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_utm 0:00:09.415855

Started | 2025-09-29 09:57:02
Ended | 2025-09-29 09:57:12
Duration | 0:00:09.415855
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:57:02:   Reading Input Data
    2025/09/29 09:57:02:   Reading metadata for VNIR detector...
    2025/09/29 09:57:03:   Calculating solar irradiance...
    2025/09/29 09:57:03:   Reading metadata for SWIR detector...
    2025/09/29 09:57:03:   Calculating solar irradiance...
    2025/09/29 09:57:03:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:57:04:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:57:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:57:04:   Computing VNIR geolayer...
    2025/09/29 09:57:04:   Computing SWIR geolayer...
    2025/09/29 09:57:05:   Starting orthorectification...
    2025/09/29 09:57:05:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/09/29 09:57:05:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:57:06:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/29 09:57:08:   Merging VNIR and SWIR data...
    2025/09/29 09:57:08:   Orthorectifying 'mask_landwater' attribute...
    2025/09/29 09:57:08:   Orthorectifying 'mask_clouds' attribute...
    2025/09/29 09:57:09:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/29 09:57:09:   Orthorectifying 'mask_haze' attribute...
    2025/09/29 09:57:09:   Orthorectifying 'mask_snow' attribute...
    2025/09/29 09:57:10:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/29 09:57:10:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/29 09:57:11:   Generating L2A metadata...

##### Captured stderr call

    2025/09/29 09:57:02:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_compute_stack 0:00:00.003524

Started | 2025-09-29 09:57:12
Ended | 2025-09-29 09:57:12
Duration | 0:00:00.003524
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_average 0:00:00.002999

Started | 2025-09-29 09:57:12
Ended | 2025-09-29 09:57:12
Duration | 0:00:00.002999
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_order_by_wvl 0:00:00.002461

Started | 2025-09-29 09:57:12
Ended | 2025-09-29 09:57:12
Duration | 0:00:00.002461
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_swir_only 0:00:00.002090

Started | 2025-09-29 09:57:12
Ended | 2025-09-29 09:57:12
Duration | 0:00:00.002090
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_vnir_only 0:00:00.002260

Started | 2025-09-29 09:57:12
Ended | 2025-09-29 09:57:12
Duration | 0:00:00.002260
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_validate_input 0:00:00.004037

Started | 2025-09-29 09:57:12
Ended | 2025-09-29 09:57:12
Duration | 0:00:00.004037
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_radiometric_transform.py 1 0:00:04.288006

### PASSED Test_Radiometric_Transformer::test_transform_TOARad2TOARef 0:00:04.288006

Started | 2025-09-29 09:57:12
Ended | 2025-09-29 09:57:16
Duration | 0:00:04.288006
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Tmp dir: /tmp/tmpxgss67k7
    2025/09/29 09:57:12:   Reading Input Data
    2025/09/29 09:57:12:   Reading metadata for VNIR detector...
    2025/09/29 09:57:12:   Calculating solar irradiance...
    2025/09/29 09:57:12:   Reading metadata for SWIR detector...
    2025/09/29 09:57:12:   Calculating solar irradiance...
    2025/09/29 09:57:12:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:57:13:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:57:13:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:57:13:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:57:13:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:57:14:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/09/29 09:57:14:   Converting TOA radiance to TOA reflectance for SWIR detector...
    Tmp dir: /tmp/tmptanc5vvm
    2025/09/29 09:57:14:   Reading Input Data
    2025/09/29 09:57:14:   Reading metadata for VNIR detector...
    2025/09/29 09:57:14:   Calculating solar irradiance...
    2025/09/29 09:57:14:   Reading metadata for SWIR detector...
    2025/09/29 09:57:15:   Calculating solar irradiance...
    2025/09/29 09:57:15:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:57:15:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:57:15:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:57:15:   Computing SNR from VNIR TOA radiance.
    2025/09/29 09:57:15:   Computing SNR from SWIR TOA radiance.
    2025/09/29 09:57:16:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/09/29 09:57:16:   Converting TOA radiance to TOA reflectance for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_optimization.py 1 0:00:16.145527

### PASSED Test_Spatial_Optimizer::test_optimize_geolayer 0:00:16.145527

Started | 2025-09-29 09:57:16
Ended | 2025-09-29 09:57:32
Duration | 0:00:16.145527
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:57:16:   Reading Input Data
    2025/09/29 09:57:16:   Reading metadata for VNIR detector...
    2025/09/29 09:57:16:   Calculating solar irradiance...
    2025/09/29 09:57:16:   Reading metadata for SWIR detector...
    2025/09/29 09:57:17:   Calculating solar irradiance...
    2025/09/29 09:57:17:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:57:17:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:57:17:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:57:17:   Computing VNIR geolayer...
    2025/09/29 09:57:18:   Computing SWIR geolayer...
    2025/09/29 09:57:18:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/09/29 09:57:18:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/09/29 09:57:18:   Preparing reference image for co-registration.
    2025/09/29 09:57:19:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/09/29 09:57:31:   Generating misregistration array.
    interpolation runtime: 0.19s
    interpolation runtime: 0.17s
    2025/09/29 09:57:31:   Transforming spatial optimization results back to sensor geometry.
    2025/09/29 09:57:32:   Applying results of spatial optimization to geolayer.

##### Captured stderr call

    2025/09/29 09:57:16:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/09/29 09:57:18:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.1% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.3% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.5% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.3% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.3% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.4% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.5% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.2% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.1% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.2% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.4% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.4% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.2% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.2% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.3% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.4% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.5% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.2% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.3% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.4% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.1% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.1% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.5% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.2% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.5% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.3% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.4% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.4% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.8% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.5% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.8% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.6% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.7% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.1% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.3% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.7% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.0% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.0% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.6% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.3% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.4% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.0% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.0% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.3% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.2% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.0% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.2% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.2% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.1% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.3% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.3% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.3% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.2% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.3% Complete  => 0:00:00
    Warping progress     |================================================--| 96.3% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.2% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.2% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:11
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:11
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:11
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:11
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:11
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:11
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:11
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:11
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:11
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:11
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:11
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:11
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:11
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:11
    	progress: |============================----------------------| 55.3% Complete  => 0:00:11
    	progress: |============================----------------------| 55.9% Complete  => 0:00:11
    	progress: |============================----------------------| 56.5% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:11
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:11
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:11
    	progress: |================================------------------| 63.4% Complete  => 0:00:11
    	progress: |================================------------------| 64.0% Complete  => 0:00:11
    	progress: |================================------------------| 64.6% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:11
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:11
    	progress: |==================================----------------| 67.1% Complete  => 0:00:11
    	progress: |==================================----------------| 67.7% Complete  => 0:00:11
    	progress: |==================================----------------| 68.3% Complete  => 0:00:11
    	progress: |==================================----------------| 68.9% Complete  => 0:00:11
    	progress: |===================================---------------| 69.6% Complete  => 0:00:11
    	progress: |===================================---------------| 70.2% Complete  => 0:00:11
    	progress: |===================================---------------| 70.8% Complete  => 0:00:11
    	progress: |====================================--------------| 71.4% Complete  => 0:00:11
    	progress: |====================================--------------| 72.0% Complete  => 0:00:11
    	progress: |====================================--------------| 72.7% Complete  => 0:00:11
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:11
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:11
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:11
    	progress: |======================================------------| 75.2% Complete  => 0:00:11
    	progress: |======================================------------| 75.8% Complete  => 0:00:11
    	progress: |======================================------------| 76.4% Complete  => 0:00:11
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:11
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:11
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:11
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:11
    	progress: |========================================----------| 79.5% Complete  => 0:00:11
    	progress: |========================================----------| 80.1% Complete  => 0:00:11
    	progress: |========================================----------| 80.7% Complete  => 0:00:11
    	progress: |=========================================---------| 81.4% Complete  => 0:00:11
    	progress: |=========================================---------| 82.0% Complete  => 0:00:11
    	progress: |=========================================---------| 82.6% Complete  => 0:00:11
    	progress: |==========================================--------| 83.2% Complete  => 0:00:11
    	progress: |==========================================--------| 83.9% Complete  => 0:00:11
    	progress: |==========================================--------| 84.5% Complete  => 0:00:11
    	progress: |===========================================-------| 85.1% Complete  => 0:00:11
    	progress: |===========================================-------| 85.7% Complete  => 0:00:11
    	progress: |===========================================-------| 86.3% Complete  => 0:00:11
    	progress: |===========================================-------| 87.0% Complete  => 0:00:11
    	progress: |============================================------| 87.6% Complete  => 0:00:11
    	progress: |============================================------| 88.2% Complete  => 0:00:11
    	progress: |============================================------| 88.8% Complete  => 0:00:11
    	progress: |=============================================-----| 89.4% Complete  => 0:00:11
    	progress: |=============================================-----| 90.1% Complete  => 0:00:11
    	progress: |=============================================-----| 90.7% Complete  => 0:00:11
    	progress: |==============================================----| 91.3% Complete  => 0:00:11
    	progress: |==============================================----| 91.9% Complete  => 0:00:11
    	progress: |==============================================----| 92.5% Complete  => 0:00:12
    	progress: |===============================================---| 93.2% Complete  => 0:00:12
    	progress: |===============================================---| 93.8% Complete  => 0:00:12
    	progress: |===============================================---| 94.4% Complete  => 0:00:12
    	progress: |================================================--| 95.0% Complete  => 0:00:12
    	progress: |================================================--| 95.7% Complete  => 0:00:12
    	progress: |================================================--| 96.3% Complete  => 0:00:12
    	progress: |================================================--| 96.9% Complete  => 0:00:12
    	progress: |=================================================-| 97.5% Complete  => 0:00:12
    	progress: |=================================================-| 98.1% Complete  => 0:00:12
    	progress: |=================================================-| 98.8% Complete  => 0:00:12
    	progress: |==================================================| 99.4% Complete  => 0:00:12
    	progress: |==================================================| 100.0% Complete  => 0:00:12

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_transform.py 17 0:00:37.209970

### PASSED Test_Geometry_Transformer::test_to_map_geometry 0:00:01.610989

Started | 2025-09-29 09:57:32
Ended | 2025-09-29 09:57:34
Duration | 0:00:01.610989
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:57:32:   Reading Input Data
    2025/09/29 09:57:32:   Reading metadata for VNIR detector...
    2025/09/29 09:57:33:   Calculating solar irradiance...
    2025/09/29 09:57:33:   Reading metadata for SWIR detector...
    2025/09/29 09:57:33:   Calculating solar irradiance...
    2025/09/29 09:57:33:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:57:33:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:57:33:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Geometry_Transformer::test_to_sensor_geometry 0:00:01.349876

Started | 2025-09-29 09:57:34
Ended | 2025-09-29 09:57:35
Duration | 0:00:01.349876
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/29 09:57:34:   Reading Input Data
    2025/09/29 09:57:34:   Reading metadata for VNIR detector...
    2025/09/29 09:57:34:   Calculating solar irradiance...
    2025/09/29 09:57:34:   Reading metadata for SWIR detector...
    2025/09/29 09:57:34:   Calculating solar irradiance...
    2025/09/29 09:57:35:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:57:35:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:57:35:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2D 0:00:02.464650

Started | 2025-09-29 09:57:35
Ended | 2025-09-29 09:57:37
Duration | 0:00:02.464650
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/09/29 09:57:35:   Reading Input Data
    2025/09/29 09:57:35:   Reading metadata for VNIR detector...
    2025/09/29 09:57:36:   Calculating solar irradiance...
    2025/09/29 09:57:36:   Reading metadata for SWIR detector...
    2025/09/29 09:57:36:   Calculating solar irradiance...
    2025/09/29 09:57:36:   Reading image masks in VNIR sensor geometry.
    2025/09/29 09:57:36:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/29 09:57:37:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/29 09:57:37:   Computing VNIR geolayer...
    2025/09/29 09:57:37:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/09/29 09:57:35:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log setup

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_2DGeolayer 0:00:00.454807

Started | 2025-09-29 09:57:37
Ended | 2025-09-29 09:57:38
Duration | 0:00:00.454807
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_3DGeolayer 0:00:00.421150

Started | 2025-09-29 09:57:38
Ended | 2025-09-29 09:57:38
Duration | 0:00:00.421150
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_2D 0:00:00.374742

Started | 2025-09-29 09:57:38
Ended | 2025-09-29 09:57:39
Duration | 0:00:00.374742
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_3D 0:00:20.908598

Started | 2025-09-29 09:57:39
Ended | 2025-09-29 09:58:00
Duration | 0:00:20.908598
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer 0:00:00.413373

Started | 2025-09-29 09:58:00
Ended | 2025-09-29 09:58:00
Duration | 0:00:00.413373
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:00.405475

Started | 2025-09-29 09:58:00
Ended | 2025-09-29 09:58:00
Duration | 0:00:00.405475
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_normalized_image_coordinates 0:00:00.003748

Started | 2025-09-29 09:58:00
Ended | 2025-09-29 09:58:00
Duration | 0:00:00.003748
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_normalize_coordinates 0:00:00.002692

Started | 2025-09-29 09:58:00
Ended | 2025-09-29 09:58:00
Duration | 0:00:00.002692
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_transform_LonLatHeight_to_RowCol 0:00:00.002960

Started | 2025-09-29 09:58:00
Ended | 2025-09-29 09:58:00
Duration | 0:00:00.002960
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:01.966503

Started | 2025-09-29 09:58:00
Ended | 2025-09-29 09:58:02
Duration | 0:00:01.966503
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_faulty_coeff_set 0:00:00.524215

Test in case of a faulty/inaccurate coeff set the result really does not contain NaNs.

NOTE: NaNs should be filled automatically.

Started | 2025-09-29 09:58:02
Ended | 2025-09-29 09:58:03
Duration | 0:00:00.524215
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_multiprocessing 0:00:03.296881

Started | 2025-09-29 09:58:03
Ended | 2025-09-29 09:58:06
Duration | 0:00:03.296881
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_singleprocessing 0:00:02.312815

Started | 2025-09-29 09:58:06
Ended | 2025-09-29 09:58:09
Duration | 0:00:02.312815
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_one_unique_coeff_set 0:00:00.696497

Started | 2025-09-29 09:58:09
Ended | 2025-09-29 09:58:09
Duration | 0:00:00.696497
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_srf.py 1 0:00:00.009062

### PASSED Test_SRF::test_from_cwl_fwhm 0:00:00.009062

Started | 2025-09-29 09:58:09
Ended | 2025-09-29 09:58:09
Duration | 0:00:00.009062
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown